envClassFileName constant
String
const envClassFileName
The name of the generated Dart environment class file.
Implementation
static const String envClassFileName = 'lib/app_environment.dart';
The name of the generated Dart environment class file.
static const String envClassFileName = 'lib/app_environment.dart';