EnvManager class
A utility class for managing environment configurations in Flutter apps.
The EnvManager reads from environment.yaml, generates a Dart class (AppEnvironment),
and updates the app version in pubspec.yaml based on the selected environment.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generateEnvClass(
[String? envArgument]) → Future< void> -
Generates the
AppEnvironmentclass and updatespubspec.yamlwith the selected environment's version.
Constants
- envClassFileName → const String
- The name of the generated Dart environment class file.
- envFileName → const String
- The name of the environment YAML file.
- pubspecFileName → const String
-
The name of the
pubspec.yamlfile.